@@ -35,13 +35,14 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 ###########################################################################
 
-from __future__ import division
-from __future__ import print_function
-from __future__ import absolute_import
-from past.builtins import cmp
-from future import standard_library
+#from __future__ import division
+#from __future__ import print_function
+#from __future__ import absolute_import
+#from past.builtins import cmp
+
+#from future import standard_library
+#standard_library.install_aliases()
 
-standard_library.install_aliases()
 from builtins import zip
 from builtins import map
 #from builtins import str
