@@ -41,12 +41,9 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 ###########################################################################
 """
-from __future__ import division
-from __future__ import print_function
-from __future__ import absolute_import
-from future import standard_library
+#from future import standard_library
+#standard_library.install_aliases()
 
-standard_library.install_aliases()
 #from builtins import str
 from builtins import range
 from builtins import object
