@@ -55,6 +55,7 @@ import types
 import fandango as fun
 from fandango.log import Logger, except2str, printf
 from fandango.excepts import *
+from fandango.threads import get_tango_thread_context
 from fandango.callbacks import *
 import fandango.tango as tango  # Double import to avoid ambiguous naming of some methods
 from fandango.tango import *  # USE_TAU imported here, get_polled_attrs and other useful methods
@@ -517,73 +518,74 @@ class Dev4Tango(PyTango.LatestDeviceImpl, log.Logger):
 
     def update_external_attributes(self):
         """This thread replaces TauEvent generation in case that the attributes are read from a device within the same server."""
-        while not self.Event.isSet():
-            waittime = 3.0
-            try:
-                serverAttributes = [
-                    a
-                    for a, v in list(self.ExternalAttributes.items())
-                    if isinstance(v, fakeAttributeValue)
-                ]
-                waittime = old_div(
-                    1e-3 * self.PollingCycle, (len(serverAttributes) + 1)
-                )
-
-                for ii, aname in enumerate(sorted(serverAttributes)):
-                    self.Event.wait(waittime)
-                    print(
-                        "ExternalAttributes %d/%d: %s"
-                        % (ii, len(serverAttributes), aname)
+        with get_tango_thread_context():
+            while not self.Event.isSet():
+                waittime = 3.0
+                try:
+                    serverAttributes = [
+                        a
+                        for a, v in list(self.ExternalAttributes.items())
+                        if isinstance(v, fakeAttributeValue)
+                    ]
+                    waittime = old_div(
+                        1e-3 * self.PollingCycle, (len(serverAttributes) + 1)
                     )
-                    self.last_update = time.time()
-                    try:
-                        if self.Event.isSet():
-                            self.events_error = "Thread finished by Event.set()"
-                            break
-                        attr = self.ExternalAttributes[aname]
-                        device, attribute = aname.rsplit("/", 1)
-                        self.debug(
-                            "====> updating values from %s(%s.%s) "
-                            "after %s s"
-                            % (type(attr.parent), device, attribute, waittime)
-                        )
-                        event_type = fakeEventType.lookup["Periodic"]
 
-                        try:
-                            attr.read(cache=False)
-                        except Exception as e:
-                            print("#" * 80)
-                            event_type = fakeEventType.lookup["Error"]
-                            self.events_error = except2str(e)  # traceback.format_exc()
-                            print(self.events_error)
-
-                        self.info(
-                            "Sending fake event: %s/%s = %s(%s)"
-                            % (device, attr.name, event_type, attr.value)
-                        )
-                        self.event_received(device + "/" + attr.name, event_type, attr)
-
-                    except:
-                        self.events_error = traceback.format_exc()
+                    for ii, aname in enumerate(sorted(serverAttributes)):
+                        self.Event.wait(waittime)
                         print(
-                            "Exception in %s.update_attributes(%s): \n%s"
-                            % (self.get_name(), attr.name, self.events_error)
+                            "ExternalAttributes %d/%d: %s"
+                            % (ii, len(serverAttributes), aname)
                         )
+                        self.last_update = time.time()
+                        try:
+                            if self.Event.isSet():
+                                self.events_error = "Thread finished by Event.set()"
+                                break
+                            attr = self.ExternalAttributes[aname]
+                            device, attribute = aname.rsplit("/", 1)
+                            self.debug(
+                                "====> updating values from %s(%s.%s) "
+                                "after %s s"
+                                % (type(attr.parent), device, attribute, waittime)
+                            )
+                            event_type = fakeEventType.lookup["Periodic"]
 
-                    # End of for
-                print("#$-" * 30)
-                self.Event.wait(waittime)
-            except:
+                            try:
+                                attr.read(cache=False)
+                            except Exception as e:
+                                print("#" * 80)
+                                event_type = fakeEventType.lookup["Error"]
+                                self.events_error = except2str(e)  # traceback.format_exc()
+                                print(self.events_error)
+
+                            self.info(
+                                "Sending fake event: %s/%s = %s(%s)"
+                                % (device, attr.name, event_type, attr.value)
+                            )
+                            self.event_received(device + "/" + attr.name, event_type, attr)
+
+                        except:
+                            self.events_error = traceback.format_exc()
+                            print(
+                                "Exception in %s.update_attributes(%s): \n%s"
+                                % (self.get_name(), attr.name, self.events_error)
+                            )
+
+                        # End of for
+                    print("#$-" * 30)
+                    self.Event.wait(waittime)
+                except:
+                    self.events_error = traceback.format_exc()
+                    self.Event.wait(3.0)
+                    print(self.events_error)
+                    print("Exception in %s.update_attributes()" % (self.get_name()))
+                # End of while
+
+            self.info("%s.update_attributes finished")
+            if not self.events_error.replace("None", "").strip():
                 self.events_error = traceback.format_exc()
-                self.Event.wait(3.0)
-                print(self.events_error)
-                print("Exception in %s.update_attributes()" % (self.get_name()))
-            # End of while
-
-        self.info("%s.update_attributes finished")
-        if not self.events_error.replace("None", "").strip():
-            self.events_error = traceback.format_exc()
-        return
+            return
 
     def event_received(self, source, type_, attr_value):
         """
