@@ -1,5 +1,4 @@
-from __future__ import print_function
-from __future__ import absolute_import
+import traceback
 
 try:
     from . import DDebug as debug
@@ -11,6 +10,7 @@ try:
     from .Dev4Tango import *
 except:
     print("Unable to import Dev4Tango")
+    traceback.print_exc()
 try:
     from . import FolderDS as folders
     from .FolderDS import FolderDS, FolderAPI
