@@ -73,6 +73,7 @@ except:
 
 from .objects import self_locked
 from .functional import *
+from .threads import ThreadDict
 
 ENC = "latin-1"
 
@@ -160,303 +161,6 @@ def json2dict(jstr, encoding=ENC):
     return d
 
 
-class ThreadDict(dict):
-    """
-    Thread safe dictionary with redefinable read/write methods and a background thread for hardware update.
-    All methods are thread-safe using @self_lock decorator.
-        NOTE: any method decorated in this way CANNOT call other decorated methods!
-    All values of the dictionary will be automatically updated in a separate Thread using read_method provided.
-    Any value overwritten in the dict should launch the write_method.
-
-    delay argument will pause the thread for a time after start() is called
-
-    Briefing:
-        a[2] equals to a[2]=read_method(2)
-        a[2]=1 equals to a[2]=write_method(2,1)
-
-    threadkeys():
-        returns the list of keys that are being automatically updated in a background thread
-    append(key,value=None,period=3000):
-        adds a new key to the dictionary and to the list of keys to be updated
-    __setitem__(key,value):tdict[key]=value
-        will also add a new key to the dictionary, but this key value will not be automatically updated.
-
-    timewait is a pause inserted between readings
-
-    If read_method defined:
-        If threaded: the Thread inserts data in the dictionary, __getitem__ retrieves this data
-        else: __getitem__ directly executes read_method
-    else: __getitem__ as a normal thread-safe dictionary
-    If write_method defined:
-        any __setitem__ call executes the write_method (dictionary is no affected)
-    else: __setitem__ as a normal thread-safe dictionary
-
-    @deprecated now in tau.core.utils.containers
-    """
-
-    def __init__(
-        self,
-        other=None,
-        read_method=None,
-        write_method=None,
-        timewait=0.1,
-        threaded=True,
-        trace=False,
-        delay=0.0,
-    ):
-        self.read_method = read_method
-        self.write_method = write_method
-        self.timewait = timewait
-        self.threaded = threaded
-        self.delay = delay
-        self._threadkeys = []
-        self._periods = {}
-        self._updates = {}
-        self.trace = trace
-        self.last_update = 0
-        self._last_read = ""
-        self.last_cycle_start = 0
-        self.cycle_count = 0
-        self.cycle_average = 0
-        self.event = threading.Event()
-        self.parent = type(self).mro()[
-            1
-        ]  # equals to self.__class__.__base__ or type(self).__bases__[0]
-        if other:
-            dict.update(self, other)
-
-    def tracer(self, text, level=0):
-        # if isinstance(self.trace,int) and level<self.trace:
-        print(text)
-
-    # @self_locked
-    def start(self):
-        if not self.threaded:
-            print("ThreadDict.start(): This Dict has no Thread!")
-            return
-        if hasattr(self, "_Thread") and self._Thread and self._Thread.isAlive():
-            print("ThreadDict.start(): ThreadDict.stop() must be executed first!")
-            return
-        if self.delay:
-            self.event.wait(self.delay)
-        print("In ThreadDict.start()")  # , keys are: %s' % self.threadkeys()
-        self.event.clear()
-        self._Thread = threading.Thread(target=self.run)
-        self._Thread.setDaemon(True)
-        self._Thread.start()
-        self.tracer("ThreadDict started!")
-
-    # @self_locked
-    def stop(self):
-        print("Stopping ThreadDict ...")
-        if self.threaded and hasattr(self, "event"):
-            # print('event set')
-            self.event.set()
-        self.event.wait(5.0e-3)
-        if hasattr(self, "_Thread"):
-            # print('thread join')
-            self._Thread.join()
-        print("ThreadDict Stopped")
-
-    def alive(self):
-        if not hasattr(self, "_Thread") or not self._Thread:
-            return None  # Thread never started
-        else:
-            return self._Thread.isAlive()  # True or False
-
-    def __del__(self):
-        self.stop()
-
-    def run(self):
-        self.tracer("In ThreadDict.run(%s)" % str(self.threadkeys()))
-        self.event.wait(self.get_timewait())
-        while not self.event.isSet():
-            self.set_last_cycle_start(time.time())
-            keys = sorted(self.threadkeys())
-            if (
-                self._last_read and self._last_read != keys[-1]
-            ):  # Thread stopped before finishing the cycle!
-                keys = keys[keys.index(self._last_read) + 1 :]
-            for k in keys:
-                try:
-                    if (time.time() - self._updates.get(k, 0)) > self._periods.get(
-                        k, 0
-                    ):
-                        # if period=0 or if not updated the condition applies
-                        if self.trace:
-                            self.tracer("ThreadDict::run(): updating %s" % str(k))
-                        self.__getitem__(k, hw=True)
-                except Exception as e:
-                    if self.trace:
-                        print(
-                            "!!! ThreadDict Exception !!!"
-                            + "\n"
-                            + "%s ..." % str(traceback.format_exc())[:1000]
-                        )
-                    self.__setitem__(k, e, hw=False)
-                finally:
-                    self._last_read = k
-                    if self.event.isSet():
-                        break
-                    else:
-                        self.event.wait(self.timewait)
-                if self.event.isSet():
-                    break
-
-            try:
-                self.cycle_average = old_div(
-                    (
-                        (self.cycle_average * self.cycle_count)
-                        + (time.time() - self.last_cycle_start)
-                    ),
-                    (self.cycle_count + 1),
-                )
-                self.cycle_count += 1
-            except:
-                traceback.print_exc()
-            self.event.wait(self.get_timewait())
-        self.tracer("End of ThreadDict")
-
-    @self_locked
-    def get_last_update(self):
-        return self.last_update
-
-    @self_locked
-    def set_last_update(self, value):
-        self.last_update = value
-
-    @self_locked
-    def get_last_cycle_start(self):
-        return self.last_cycle_start
-
-    @self_locked
-    def set_last_cycle_start(self, value):
-        self.last_cycle_start = value
-
-    @self_locked
-    def get_timewait(self):
-        return self.timewait
-
-    @self_locked
-    def set_timewait(self, value):
-        self.timewait = value
-
-    @self_locked
-    def append(self, key, value=None, period=0):
-        """
-        args: key, value=None, period=0
-        periods shall be specified in seconds
-        period=0 means that attribute will be updated every timewait*length
-        """
-        if key not in self:
-            self.parent.__setitem__(self, key, value)
-        if key not in self._threadkeys:
-            self._threadkeys.append(key)
-            self._periods[key] = period
-        if self.trace:
-            self.tracer("ThreadDict.append(%s,%s,%s)" % (key, value, period))
-
-    @self_locked
-    def threadkeys(self):
-        return self._threadkeys[:]
-
-    @self_locked
-    def __locked_setitem__(self, key, value):
-        return dict.__setitem__(self, key, value)
-
-    @self_locked
-    def __locked_getitem__(self, key):
-        return dict.__getitem__(self, key)
-
-    @self_locked
-    def __locked_getitem_hw__(self, key):
-        return self.__getitem__(key, hw=True)
-
-    def __getitem__(self, key, hw=False):
-        """This method launches a read_method execution if there's no thread on charge of doing that or if the hw flag is set to True."""
-        if self.trace:
-            print("In ThreadDict.__getitem__(%s,%s)" % (key, hw))
-        if (
-            hw or not self.threaded
-        ):  # HW ACCESS MUST NOT BE DONE WITHOUT ASKING EXPLICITLY! (Use __setitem__(k,None) instead)
-            self._updates[key] = time.time()
-            if self.read_method:
-                value = self.read_method(key)
-                self.__locked_setitem__(key, value)
-                self.set_last_update(self._updates[key])
-        return self.__locked_getitem__(key)
-
-    def __setitem__(self, key, value, hw=True):
-        """This method launches a write_method execution if the hw flag is not explicitly set to False."""
-        if self.trace:
-            print("In ThreadDict.__setitem__(%s,...,%s)" % (key, hw))
-        if hw and self.write_method:
-            # It implies that a key will not be added here to read thread!
-            nvalue = self.write_method(*[key, value])
-            self.__locked_setitem__(key, nvalue)
-        else:
-            self.__locked_setitem__(key, value)
-        self.set_last_update(time.time())
-
-    @self_locked
-    def get(self, key, default=None, hw=False):
-        if hw:
-            self.__locked_getitem_hw__(key)
-        elif not self.threaded and self.read_method:
-            dict.__setitem__(self, key, self.read_method(key))
-            self.last_update = time.time()
-        if default is False:
-            return dict.get(self, key)
-        else:
-            return dict.get(self, key, default)
-
-    @self_locked
-    def __delitem__(self, key):
-        return dict.__delitem__(self, key)
-
-    @self_locked
-    def __contains__(self, key):
-        return dict.__contains__(self, key)
-
-    @self_locked
-    def has_key(self, key):
-        return key in self
-
-    @self_locked
-    def __iter__(self):
-        return dict.__iter__(self)
-
-    @self_locked
-    def pop(self, key):
-        return dict.pop(self, key)
-
-    @self_locked
-    def __str__(self):
-        return (
-            "{"
-            + ",".join(
-                [
-                    "'" + str(k) + "'" + ":" + "'" + str(v) + "'"
-                    for k, v in zip(dict.keys(self), dict.values(self))
-                ]
-            )
-            + "}"
-        )
-
-    @self_locked
-    def __repr__(self):
-        return (
-            "{\n"
-            + "\n,".join(
-                [
-                    "'" + str(k) + "'" + ":" + "'" + str(v) + "'"
-                    for k, v in zip(dict.keys(self), dict.values(self))
-                ]
-            )
-            + "\n}"
-        )
-
-
 class defaultdict_fromkey(defaultdict):
     """Creates a dictionary with a default_factory function that creates new elements using key as argument.
     Usage : new_dict = defaultdict_fromkey(method); where method like (lambda key: return new_obj(key))
