@@ -1280,7 +1280,7 @@ def bin2signedint(x, N=16):
     return i
 
 
-def int2bool(dec, N=16):
+def int2flags(dec, N=16):
     """Converts an integer to a binary represented as a boolean array"""
     result, dec = [], int(dec)
     for i in range(N):
@@ -1288,6 +1288,11 @@ def int2bool(dec, N=16):
         dec = dec >> 1
     return result
 
+def int2bool(*args,**kwargs):
+    #@DEPRECATED
+    print('int2bool is misleading and deprecated, use int2flags instead')
+    return int2flags(*args,**kwargs)
+
 
 def bool2int(seq):
     """Converts a boolean array to an unsigned integer"""
