@@ -92,7 +92,7 @@ except:
 ## Inspection methods
 
 
-def dirModule(module):
+def dir_module(module):
     """
     instead of dir(module) that returns everything imported in a file
     this dirModule() method retuns only the methods explicitly declared
@@ -104,8 +104,10 @@ def dirModule(module):
         if getattr(v, "__module__", "") == module.__name__
     ]
 
+dirModule = dir_module
 
-def findModule(module):
+
+def find_module(module):
     """
     returns the path to a python module
     """
@@ -121,36 +123,32 @@ def findModule(module):
         return pchild
 
 
-find_module = findModule
+findModule = find_module
 
 
-def loadModule(module, modulename=None):
+def load_module(module, modulename=None):
     """
     Loads a python module either from source file or from module
     """
-    import imp
-
-    if modulename or "/" in module or ".py" in module:
+    import sys, importlib       
+    if '/' in module or '.py' in module:
         if not modulename:
             modulename = module.split("/")[-1].split(".py")[0]
             modulename = replaceCl("[-\.]", "_", modulename)
-
-        return imp.load_source(modulename, module)
-
-    elif "." not in module:
-        return imp.load_module(module, *imp.find_module(module))
-
+            
+        spec = importlib.util.spec_from_file_location(modulename, module)
+        
     else:
-        parent, child = module.rsplit(".", 1)
-        mparent = loadModule(parent)
-        args = imp.find_module(child, mparent.__path__)
-        mchild = imp.load_module(module, *args)
-        return mchild
+        spec = importlib.util.find_spec(module)
+        
+    m = importlib.util.module_from_spec(spec)
+    spec.loader.exec_module(m)
+    return m
+
+loadModule = load_module
 
 
-load_module = loadModule
-
-def getModuleName(o):
+def get_module_name(o):
     """
     returns module name of an object
     """    
@@ -160,17 +158,20 @@ def getModuleName(o):
     o = inspect.getmodule(o)
     return getattr(o,'__name__','')
 
-get_module_name = getModuleName
+getModuleName = get_module_name
 
-def dirClasses(module, owned=False):
+
+def dir_classes(module, owned=False):
     v = [a for a, v in list(module.__dict__.items()) if isinstance(v, type)]
     if owned:
         return [a for a in dirModule(module) if a in v]
     else:
         return v
+    
+dirClasses = dir_classes
+    
 
-
-def getCode(obj, deep=True):
+def get_code(obj, deep=True):
     import inspect
     try:
         f = inspect.getsource(obj)
@@ -191,6 +192,8 @@ def getCode(obj, deep=True):
         )
     except:
         return Struct(header=str(obj), doc="", source="", children=None)
+    
+getCode = get_code
 
 
 def copy(obj):
@@ -325,11 +328,11 @@ class Struct(object):
 
     def load(self, *args, **kwargs):
         dct = args[0] if len(args) == 1 else (args or kwargs)
-        if isSequence(dct) and not isDictionary(dct):
+        if isSequence(dct) and len(dct) and not isSequence(dct[0]):
             dct = dict.fromkeys(dct)  # isDictionary also matches items lists
         [
             setattr(self, k, v)
-            for k, v in (list(dct.items()) if hasattr(dct, "items") else dct)
+            for k, v in (dct.items() if hasattr(dct, "items") else dct)
         ]
 
     # Overriding dictionary methods
