@@ -38,7 +38,7 @@
 ## Inspired by Maxim Krikun [ http://code.activestate.com/recipes/276960-shell-like-data-processing/?in=user-1085177]
 ########################################################################
 
-from builtins import str
+#from builtins import str
 from builtins import object
 from fandango.functional import *
 
