@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 from __future__ import print_function
-from builtins import str
+#from builtins import str
 from builtins import range
 
 __doc__ = """
