@@ -46,7 +46,7 @@ Methods for Astor-like management will go to fandango.servers
 from __future__ import division
 from __future__ import print_function
 
-from builtins import str
+#from builtins import str
 from builtins import zip
 from builtins import map
 from builtins import range
